@@ -202,7 +202,7 @@ my.add_change('')
 for i in (new_desktop, removed_desktop, new_icons, removed_icons, archis, pkgrenames, codecs, icons):
 	a = i.write()
 	if a.strip():
-		my.add_change(a)
+		my.add_change(unicode(a, "utf-8"))
 my.add_change('')
 
 my.write_to_open_file(open('changelog.verbose', 'w'))
